uniform sampler2D texture0;
uniform sampler2D texture0alpha;
varying lowp float alphaVal;
varying mediump vec2 uv0;
varying mediump vec2 uv1;

#ifdef USE_SPECULAR
#ifndef PAINT_IN_SHADOW
uniform sampler2D normalMap;
varying lowp vec3 lightDir;
varying highp vec2 uv2;
#endif
#endif

#ifdef USE_ADJUST_SATURATION		
	#include "adjust_saturation.fs"			
#endif

void main()
{
	lowp vec4 alpha = vec4(texture2D(texture0, uv1).xyz, texture2D(texture0alpha, uv1).x);

#ifdef PAINT_IN_SHADOW

	//gl_FragColor = vec4(0.10, 0.11, 0.32, alpha.a * alphaVal);
	
	#ifdef USE_ADJUST_SATURATION	
		gl_FragColor = desaturate(vec4(0.10, 0.11, 0.32, alpha.a * alphaVal));
	#else
		gl_FragColor = vec4(0.10, 0.11, 0.32, alpha.a * alphaVal);
	#endif

#else

	lowp vec3 textureColor = texture2D(texture0, uv0).rgb;

#ifdef USE_SPECULAR
	highp float SpecularIntensity = 0.8;
	highp float Shininess = 3.0;
	
	highp vec3 normalValue = texture2D(normalMap, uv2).rgb;

	//normalize
	highp float nx = normalValue.x*2.0 - 1.0;
	highp float ny = -(normalValue.y*2.0 - 1.0);
	highp vec3 fragNormal = vec3(nx, ny, sqrt(1.0 - nx*nx - ny*ny));

	highp float NdotH = max(dot(fragNormal, lightDir), 0.0);
	highp float specComponent = pow( NdotH, Shininess) * SpecularIntensity;

	//gl_FragColor = vec4( textureColor + specComponent, alpha.a * alphaVal );
	
	#ifdef USE_ADJUST_SATURATION	
		gl_FragColor = desaturate(vec4( textureColor + specComponent, alpha.a * alphaVal ));
	#else
		gl_FragColor = vec4( textureColor + specComponent, alpha.a * alphaVal );
	#endif
#else
	//gl_FragColor = vec4( textureColor , alpha.a * alphaVal );
	
#ifdef USE_ADJUST_SATURATION	
	gl_FragColor = desaturate(vec4( textureColor , alpha.a * alphaVal ));
#else
	gl_FragColor = vec4( textureColor , alpha.a * alphaVal );
#endif

#endif //USE_SPECULAR

#endif
}
