#ifndef PAINT_IN_SHADOW
uniform sampler2D diffuseMap;
uniform sampler2D specularMap;

varying lowp float NdotL;
varying highp vec2 uv0;
varying highp vec2 uv1;
#endif

#ifdef USE_ADJUST_SATURATION		
	#include "adjust_saturation.fs"			
#endif

void main()
{
#ifdef PAINT_IN_SHADOW

	//gl_FragColor = vec4(0.10, 0.11, 0.32, 1.0);
	
#ifdef USE_ADJUST_SATURATION	
	gl_FragColor = desaturate(vec4(0.10, 0.11, 0.32, 1.0));
#else
	gl_FragColor = vec4(0.10, 0.11, 0.32, 1.0);
#endif
	
#else

	lowp vec3 textureColor = texture2D(diffuseMap, uv0).rgb;
	
	lowp vec3 specularColor = texture2D(specularMap, uv1).rgb;

	highp float SpecularIntensity = 6.5;
	highp float Shininess = 10.0;
	
	highp vec3 ambientColor = vec3(0.08, 0.43, 0.24);
	highp vec3 diffuseColor = vec3(0.24, 1.0, 0.2);

	highp vec3 colorComponent = diffuseColor*NdotL + ambientColor*(1.0 - NdotL);

#ifdef USE_SPECULAR	
	highp float hndotl = NdotL;//the pow needs a highp to work correctly
	lowp float specComponent = SpecularIntensity * pow(hndotl, Shininess);
	colorComponent = colorComponent + specComponent;
#endif // USE_SPECULAR	
	
	lowp vec3 textureComponent = 1.0 - ((1.0 - textureColor) * (1.0 - specularColor));
	lowp vec3 color = (colorComponent + textureComponent) * 0.5;
	//gl_FragColor = vec4(color, 1.0);
	
#ifdef USE_ADJUST_SATURATION	
	gl_FragColor = desaturate(vec4(color, 1.0));
#else
	gl_FragColor = vec4(color, 1.0);
#endif
			
#endif
}