varying mediump vec2 uv0;
uniform sampler2D texture0;
uniform sampler2D texture0alpha;


#if (defined(USE_VERTEX_COLOR) || defined(USE_CURVE_CORRECTION))
varying lowp vec4 vtxColor;
#endif

#ifdef USE_CURVE_CORRECTION
uniform sampler2D correctionMap;
uniform int inPalette;
#endif

#ifdef USE_ADJUST_SATURATION
	#include "adjust_saturation.fs"
#endif

void main()
{
	highp vec4 color = vec4(texture2D(texture0, uv0).xyz, texture2D(texture0alpha, uv0).x);

#ifdef USE_CURVE_CORRECTION
	// aprox 30% of the red value, 59% of the green value, and 11% of the blue value
	// this converts from RGB to luminance. 
	// inPalette pixelLine selected on gradient map.
	// 0.00390625 conversion from 0->255 to 0.0->1.0. Change it if gradient map size is changed.
	highp vec2 texCoords = vec2( color.r * 0.295 + color.g * 0.585 + color.b * 0.105 , float(inPalette) * 0.00390625 + 0.002);
	color = vec4( texture2D(correctionMap, texCoords).rgb, vtxColor.a * color.a );
#endif

#ifdef USE_VERTEX_COLOR
	color = vtxColor * color;
#endif

#ifdef USE_ADJUST_SATURATION
	gl_FragColor = desaturate(color);
#else
	gl_FragColor = color;
#endif
}
