varying highp vec3 gnormal;
varying lowp float vSpecIntensity; //gnormal.z * specintensity (loc_SpecularIntensity3 or 0.13)
varying highp vec3 eyeDir;
varying highp vec2 uv0;
varying highp vec2 uv1;
varying highp vec2 uv2;

uniform sampler2D paletteMap;
uniform sampler2D normalMap;
uniform sampler2D maskMap;

#ifdef USE_TEXTURE_SPECULAR
uniform sampler2D specularMap;
#endif

void main()
{
//#ifdef TEST_FS
	lowp vec3 MK = texture2D(maskMap, uv2).xyz;
	lowp vec3 fragNormal0 = texture2D(normalMap, uv0).xyz;
	lowp vec3 fragNormal1 = texture2D(normalMap, uv1).xyz;
	lowp vec3 fragNormal = (fragNormal0 + fragNormal1 - 1.0); //make them from -0.5 to 0.5

	highp vec3 n = normalize(fragNormal * gnormal); //the normal is scaled in the vs to -0.5 to 0.5 as well

	highp vec3 lightDir = vec3(0.0, 0.7071, 0.7071);

	// fresnel lighting
	highp float NdotE = dot(n, eyeDir);
	lowp vec3 diffuseCol = texture2D(paletteMap, vec2(0.0, NdotE)).rgb;

	lowp vec3 color = diffuseCol;

#ifdef USE_TEXTURE_SPECULAR
	highp float NdotH = dot(n, lightDir);
	highp float NdotH3 = dot(fragNormal, lightDir);
	highp vec2 coord = vec2(NdotH, NdotH3);
	lowp vec3 specValue = texture2D(specularMap, coord).xyz;
	lowp vec3 finalColor = color + specValue.x + specValue.y * vSpecIntensity;
#endif

#ifdef USE_CALCULATED_SPECULAR
	const highp float loc_Shininess3 = 10.0;
	highp float NdotH3 = dot(fragNormal, lightDir);
	highp float specIntensity3 = pow(NdotH3, loc_Shininess3);
	highp vec3 finalColor = (color + specIntensity3 * vSpecIntensity);
#endif

	//gl_FragColor = vec4(finalColor + MK, 0.5); //LMQuang removed
//#endif
//	gl_FragColor = vec4(0.0, 0.7, 1.0, 0.6);

#ifdef USE_ADJUST_SATURATION
	gl_FragColor = desaturate(vec4(finalColor + MK, 0.5));
#else
	gl_FragColor = vec4(finalColor + MK, 0.5);
#endif	

}
