uniform highp mat4 inViewProjMatrix;
uniform highp mat4 inWorldMatrix;
uniform lowp float waterY;

attribute vec3 inPos;

#ifdef CALCULATE_LIGHT
uniform highp vec3 inPLightPos[8];
uniform highp vec3 inCameraPos;

attribute vec3 inNormal;
attribute vec2 inUV0;
attribute vec2 inUV1;

varying highp vec3 eyeDir;
varying highp vec2 uv0;
varying highp vec2 uv1;
varying highp vec2 uv2;
varying highp vec3 gnormal;
varying lowp float vSpecIntensity;
#endif

const highp float pi2 = 3.14159 * 2.0;
uniform highp float time;

highp float waveHeight(highp float x, highp float y)
{
	highp float height = 0.0;

	// Paco liked this!
	vec4 loc_speed = vec4(0.1, 0.2, 0.3, 0.03);
	vec4 loc_wavelength = vec4(0.9, 0.7, 0.2, 0.1);
	vec4 loc_amplitude = vec4(0.05, 0.05, 0.01, 0.0);

	// first wave position
	highp float frequency0 = pi2 / loc_wavelength.x;
	highp float phase0 = loc_speed.x * frequency0;
	highp float theta0 = x;
	highp float angle0 = theta0 * frequency0 + time * phase0;
	height += loc_amplitude.x * sin(angle0);


	// second wave position
	highp float frequency1 = pi2 / loc_wavelength.y;
	highp float phase1 = loc_speed.y * frequency1;
	highp float theta1 = y;
	highp float angle1 = theta1 * frequency1 + time * phase1;
	height += loc_amplitude.y * sin(angle1);


	// third wave position
	highp float frequency2 = pi2 / loc_wavelength.z;
	highp float phase2 = loc_speed.z * frequency2;
	highp float theta2 = dot(vec2(-0.707, -0.707), vec2(x, y));
	highp float angle2 = theta2 * frequency2 + time * phase2;
	height += loc_amplitude.z * sin(angle2);


	// fourth wave position
	highp float frequency3 = pi2 / loc_wavelength.w;
	highp float phase3 = loc_speed.w * frequency3;
	highp float theta3 = dot(vec2(-0.5, -0.866), vec2(x, y));
	highp float angle3 = theta3 * frequency3 + time * phase3;
	height += loc_amplitude.w * sin(angle3);

	return height * 0.1;
}

void main()
{
	highp vec4 worldPos = inWorldMatrix * vec4(inPos.xyz,1.0);

	vec3 waveNormal;
	worldPos.y += waterY;
	worldPos.y -= waveHeight(worldPos.x, worldPos.y);

	gl_Position = inViewProjMatrix * worldPos;

#ifdef CALCULATE_LIGHT
	highp vec3 pos = inPos.xyz;
	eyeDir = normalize(inCameraPos - pos);

	highp vec2 loc_normalMapScale = vec2(0.6, 1.0);
	highp vec2 loc_normalMapSpeed = vec2(0.10, 0.13);

	highp vec2 temp = vec2(worldPos.x, worldPos.z);
	uv0.xy = temp.xy * loc_normalMapScale.x + vec2(fract(time * loc_normalMapSpeed.x), 0.0);
	uv1.xy = temp.xy * loc_normalMapScale.y + vec2(0.0, fract(time * loc_normalMapSpeed.y));

	uv0.x += -inPos.y;
	uv1.x += -inPos.y;
	
	uv2 = inUV1;
	
	gnormal = inNormal.xyz;
	vSpecIntensity = gnormal.z * 0.23;
#endif
}
